package hardcaml_circuits

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Round_robin_with_priority.Onehot_cleanerSource

Round-robin arbiter implementation which converts the masked priority vector to onehot to select the first active source.

Sourceval combinational : 'a combinational
Sourceval sequential : sequential